@@ -59,6 +59,13 @@ def index():
     return ';)'
 
 
+@app.route('/robots.txt', methods=['GET'])
+def robots_txt():
+    return """User-agent: *
+Disallow: /
+"""
+
+
 @app.route('/ping', methods=['GET'])
 def ping():
     db.connect()
